@@ -5,7 +5,7 @@ XXX
 """
 
 #
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 The SCons Foundation
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -27,26 +27,34 @@ XXX
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/ilink32.py 3266 2008/08/12 07:31:01 knight"
+__revision__ = "src/engine/SCons/Tool/ilink32.py issue-2856:2676:d23b7a2f45e8 2012/08/05 15:38:28 garyo"
 
 import SCons.Tool
 import SCons.Tool.bcc32
 import SCons.Util
 
 def generate(env):
-    """Add Builders and construction variables for ilink to an
+    """Add Builders and construction variables for Borland ilink to an
     Environment."""
+    SCons.Tool.createSharedLibBuilder(env)
     SCons.Tool.createProgBuilder(env)
 
     env['LINK']        = '$CC'
     env['LINKFLAGS']   = SCons.Util.CLVar('')
-    env['LINKCOM']     = '$LINK -q $LINKFLAGS $SOURCES $LIBS'
+    env['LINKCOM']     = '$LINK -q $LINKFLAGS -e$TARGET $SOURCES $LIBS'
     env['LIBDIRPREFIX']=''
     env['LIBDIRSUFFIX']=''
     env['LIBLINKPREFIX']=''
     env['LIBLINKSUFFIX']='$LIBSUFFIX'
 
+
 def exists(env):
     # Uses bcc32 to do linking as it generally knows where the standard
     # LIBS are and set up the linking correctly
     return SCons.Tool.bcc32.findIt('bcc32', env)
+
+# Local Variables:
+# tab-width:4
+# indent-tabs-mode:nil
+# End:
+# vim: set expandtab tabstop=4 shiftwidth=4:
