@@ -11,7 +11,7 @@ tar.gz consisting of the source file and a specfile.
 """
 
 #
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 The SCons Foundation
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -33,12 +33,12 @@ tar.gz consisting of the source file and a specfile.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/rpm.py 3363 2008/09/06 07:34:10 scons"
+__revision__ = "src/engine/SCons/Tool/rpm.py issue-2856:2676:d23b7a2f45e8 2012/08/05 15:38:28 garyo"
 
 import os
 import re
 import shutil
-import popen2
+import subprocess
 
 import SCons.Builder
 import SCons.Node.FS
@@ -67,11 +67,12 @@ def build_rpm(target, source, env):
     env.Prepend( RPMFLAGS = '--define \'_topdir %s\'' % tmpdir )
 
     # now call rpmbuild to create the rpm package.
-    handle  = popen2.Popen3( get_cmd(source, env), capturestderr=1 )
-    output  = handle.fromchild.read()
-    #output += handle.childerr.read()
-    output  = output + handle.childerr.read()
-    status  = handle.wait()
+    handle  = subprocess.Popen(get_cmd(source, env),
+                               stdout=subprocess.PIPE,
+                               stderr=subprocess.STDOUT,
+                               shell=True)
+    output = handle.stdout.read()
+    status = handle.wait()
 
     if status:
         raise SCons.Errors.BuildError( node=target[0],
@@ -123,3 +124,9 @@ def generate(env):
 
 def exists(env):
     return env.Detect('rpmbuild')
+
+# Local Variables:
+# tab-width:4
+# indent-tabs-mode:nil
+# End:
+# vim: set expandtab tabstop=4 shiftwidth=4:
